@@ -11,7 +11,7 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: IvmConfigBase.h,v 1.12 2005/05/12 01:42:34 ro_han Exp $
+ * $Id: IvmConfigBase.h,v 1.13 2005/11/06 12:29:47 ro_han Exp $
  *****************************************************************************/
 
 #ifndef _IVMCONFIGBASE_H
@@ -23,11 +23,15 @@ typedef struct IvmConfigBase
 {
     gboolean fork;
     gboolean debug;
+    gboolean sleep;
     char *configPath;
     char *pidFile;
     char *user;
     char *group;
+    char *mountcommand;
+    char *umountcommand;
+    char *umask;
 } IvmConfigBase;
 
-IvmConfigBase * parseIvmConfigBase(char const * const path);
+IvmConfigBase *parseIvmConfigBase(char const *const path);
 #endif
