@@ -11,7 +11,7 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: IvmConfigCommon.c,v 1.11 2006/02/10 01:20:51 ro_han Exp $
+ * $Id: IvmConfigCommon.c,v 1.12 2006/04/18 03:15:12 ro_han Exp $
  *****************************************************************************/
 
 // Common functions which more than one IvmConfig* needs to call.
@@ -137,7 +137,12 @@ gboolean ivm_device_is_mountable(char const *udi)
        3) volume.policy.should_mount == TRUE
           OR {
                volume.policy.should_mount does not exist
-               AND storage.policy.should_mount == TRUE on block.storage_device
+               AND { storage.policy.should_mount == TRUE on block.storage_device
+                     OR { storage.policy.should_mount does not exist on
+                          block.storage_device AND storage.removable == TRUE on
+                          block.storage_device
+                        }
+                   }
           }
      */
 
@@ -197,12 +202,20 @@ is specified"), device);
         if (!libhal_device_property_exists
             (hal_ctx, new_udi, "storage.policy.should_mount", &dbus_error))
         {
-            DEBUG(_("\
+            // OK, so no storage policy was specified anywhere.  Now we'll mount
+            // if parent device is removable.
+            if (
+              !libhal_device_property_exists( hal_ctx, new_udi, "storage.removable", &dbus_error ) ||
+              !libhal_device_get_property_bool( hal_ctx, new_udi, "storage.removable", &dbus_error )
+            ) {
+                DEBUG(_("\
 Device %s won't be mounted because no mount policy was specified on \
-either the volume or parent device"), device);
-            libhal_free_string(device);
-            libhal_free_string(new_udi);
-            return FALSE;
+volume or storage device and storage device does not appear to be removable"), device
+                );
+                libhal_free_string( device );
+                libhal_free_string( new_udi );
+                return FALSE;
+            }
         }
         else if (
                  !libhal_device_get_property_bool(hal_ctx,
@@ -237,7 +250,8 @@ to mount"), device);
     /* Sufficient conditions for a volume to _not_ be mountable: (just one 
        of these being true is sufficient)
        1) volume is a disc with no data 
-	   2) storage.automount_enabled_hint = false on block.storage_device
+       2) storage.automount_enabled_hint = false on block.storage_device
+       3) volume.is_mounted == true
      */
     if (libhal_device_property_exists
         (hal_ctx, udi, "volume.disc.has_data", &dbus_error)
@@ -252,11 +266,12 @@ Device %s can't be mounted because it is a disc with no data tracks"), device);
     }
     // if we get here, condition one is not satisfied
     if ( libhal_device_property_exists(
-	  hal_ctx,
-	  udi,
-	  "block.storage_device",
-	  &dbus_error
-	) ) {
+           hal_ctx,
+           udi,
+           "block.storage_device",
+           &dbus_error
+         )
+       ) {
         char *new_udi = (char *) libhal_device_get_property_string(
           hal_ctx,
           udi,
@@ -286,6 +301,18 @@ Device %s can't be mounted because it is a disc with no data tracks"), device);
         }
         libhal_free_string(new_udi);
     }
+    
+    if (libhal_device_property_exists
+        (hal_ctx, udi, "volume.is_mounted", &dbus_error)
+        && (libhal_device_get_property_bool(hal_ctx, udi,
+                                            "volume.is_mounted",
+                                            &dbus_error)))
+    {
+        DEBUG(_("\
+Won't try to mount device %s, as it is already mounted"), device);
+        libhal_free_string(device);
+        return FALSE;
+    }
 
 
     // yay, we made it!!!
