@@ -11,45 +11,48 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: common.h,v 1.18 2005/05/12 01:42:33 ro_han Exp $
+ * $Id: common.h,v 1.23 2005/11/29 06:23:09 ro_han Exp $
  *****************************************************************************/
 
 #ifndef _COMMON_H
 #define _COMMON_H
+
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+# ifndef _CONFIG_H
+#  define _CONFIG_H
+#  include "../config.h"
+# endif
 #else
-#error "No config.h!"
+# error "No config.h!"
 #endif
 
 #ifndef __GNUC__
 #define __FUNCTION__   ""
 #endif
 
-#include "debug.h"
-#define DEBUG(fmt, arg...) debug(fmt, __FILE__, __LINE__, __FUNCTION__, ## arg)
-
-
-#include <libhal.h>
-#include "hal_compat.h"
-LibHalContext *hal_ctx;
-
-#include "dbus_interface.h"
-
-#include "IvmConfig/IvmConfigBase.h"
-IvmConfigBase * cfg_base;
-
+#include <locale.h>
+#include <gettext.h>
+#define _(str) gettext(str)
 
 #include <glib.h>
+#include <libhal.h>
+
+
+#include "hal_compat.h"
+#include "dbus_interface.h"
+#include "debug.h"
+#define DEBUG(fmt, arg...) debug(fmt,__FILE__,__LINE__,__FUNCTION__,##arg)
+#include "IvmConfig/IvmConfigBase.h"
+
+IvmConfigBase *cfg_base;
 gboolean isdaemon;
 gboolean usermode;
 GHashTable *devices;
 GHashTable *execuns;
 GHashTable *pss;
+GMainLoop *loop;
+LibHalContext *hal_ctx;
 
-#define xmlReadFailed(filename) DEBUG("Could not parse %s!\n\
-    Please check this file for errors - read 'man %s' for some tips\n\
-    (e.g., how to use special characters such as <,> and &).\n\
-    Execution will continue, but rules in %s may not be executed.",filename,filename,filename);
+void xmlReadFailed(char const * filename);
 
 #endif
