@@ -1,3 +1,4 @@
+
 /****************************************************************************
  *
  * All portions copyright their respective authors.  All rights reserved.
@@ -10,20 +11,18 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: dbus_interface.c,v 1.3 2005/05/12 01:42:34 ro_han Exp $
+ * $Id: dbus_interface.c,v 1.6 2005/11/29 00:42:48 ro_han Exp $
  *****************************************************************************/
- 
+
 #include <dbus/dbus.h>
 #include <stdlib.h>
 
 #include "dbus_interface.h"
 #include "common.h"
 
-void
-ivm_check_dbus_error(const DBusError * error)
+void ivm_check_dbus_error(const DBusError * error)
 {
-    if (dbus_error_is_set(error))
-    {
-        DEBUG("DBus Error!  %s: %s", error->name, error->message);
+    if (dbus_error_is_set(error)) {
+        DEBUG(_("DBus Error! %s: %s"), error->name, error->message);
     }
 }
