@@ -11,7 +11,7 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: manager.c,v 1.72 2006/02/10 01:20:51 ro_han Exp $
+ * $Id: manager.c,v 1.74 2006/04/18 04:20:23 ro_han Exp $
  ************************************************************************/
 
 #define _GNU_SOURCE
@@ -1197,18 +1197,28 @@ void setupHAL()
 #endif
 
     // Now try to watch all properties, if necessary.
-    char *file = ivm_get_config_file("IvmConfigProperties.xml");
+    char * propfile = ivm_get_config_file("IvmConfigProperties.xml");
     IvmConfigProperties *prop_cfg =
-        parseIvmConfigProperties(file, NULL, NULL);
+        parseIvmConfigProperties(propfile, NULL, NULL);
+    char * actionfile = ivm_get_config_file("IvmConfigActions.xml");
+    IvmConfigActions *action_cfg =
+        parseIvmConfigActions(actionfile, NULL);
 
     if ( !prop_cfg ) {
         xmlReadFailed(" IvmConfigProperties.xml ");
     }
+    else if ( prop_cfg->checkOnInit ) {
+        DEBUG(_("Will run through properties for every device currently attached\n"));
+    }
+    
+    if ( !action_cfg ) {
+        xmlReadFailed(" IvmConfigActions.xml ");
+    }
+    else if ( action_cfg->checkOnInit ) {
+        DEBUG(_("Will run through actions for every device currently attached\n"));
+    }
 
-    else {
-        if ( prop_cfg->checkOnInit ) {
-            DEBUG(_
-                  (" Running through rules for every current property.\n"));
+    if ( ( prop_cfg && prop_cfg->checkOnInit ) || ( action_cfg && action_cfg->checkOnInit ) ) {
 
             // run through every device
             int num_devices;
@@ -1217,8 +1227,7 @@ void setupHAL()
                                                  &dbus_error);
 
             if ( !devices ) {
-                DEBUG(_
-                  (" Couldn't enumerate all devices!\n"));
+                DEBUG(_(" Couldn't enumerate all devices!\n"));
 #ifndef HAL_0_4
                 ivm_check_dbus_error(&dbus_error);
 #endif
@@ -1229,12 +1238,17 @@ void setupHAL()
             while ( devices && ( i < num_devices ) )
             {
                 //DEBUG(_("Currently checking device %s"), devices[i]);
-                IvmConfigProperties *newProp_cfg =
-                    IvmConfigPropertiesAll(file, devices[i]);
+                if ( action_cfg && action_cfg->checkOnInit )
+                    ivm_media_changed( devices[i] );
+                
+                if ( prop_cfg && prop_cfg->checkOnInit ) {
+                    IvmConfigProperties *newProp_cfg =
+                      IvmConfigPropertiesAll(propfile, devices[i]);
 
-                ivm_run_commands(newProp_cfg->exec, devices[i], FALSE);
-                ivm_free_str_array(newProp_cfg->exec);
-                free(newProp_cfg);
+                    ivm_run_commands(newProp_cfg->exec, devices[i], FALSE);
+                    ivm_free_str_array(newProp_cfg->exec);
+                    free(newProp_cfg);
+                }
 
                 i++;
             }
@@ -1245,10 +1259,13 @@ void setupHAL()
         }
 
 
+    if ( prop_cfg )
         free(prop_cfg);
-    }
+    if ( action_cfg )
+        free(action_cfg);
 
-    free(file);
+    free(actionfile);
+    free(propfile);
 
     ivm_check_dbus_error(&dbus_error);
 }
