@@ -11,7 +11,7 @@
  * 
  * See http://www.troll.no/qpl for QPL licensing information.
  *
- * $Id: manager.h,v 1.14 2005/05/12 01:42:34 ro_han Exp $
+ * $Id: manager.h,v 1.15 2005/11/06 12:29:47 ro_han Exp $
  *****************************************************************************/
 
 #ifndef _MANAGER_H
@@ -22,15 +22,15 @@ void ivm_media_changed(char const *const udi);
 void ivm_load_config();
 void ivm_sighup_handler(int const sig);
 void ivm_umount_if_needed(char const *const mountpoint);
-//void ivm_unlock_device(char const *const);
 
 char *ivm_get_config_file(char const *const filename);
-gboolean ivm_run_command(char const *const command, char const * udi,
-                     gboolean const execun);
+gboolean ivm_run_command(char const *const command, char const *udi,
+                         gboolean const execun);
 
 // Run an array of commands
-void ivm_run_commands(char ** commands, char const * udi, gboolean const execun);
+void ivm_run_commands(char **commands, char const *udi,
+                      gboolean const execun);
 
 // Free an array of strings
-void ivm_free_str_array(char ** strings);
+void ivm_free_str_array(char **strings);
 #endif
